@@ -331,6 +331,8 @@ update_stylesheet (HdyStyleManager *self)
       g_object_set (gtk_settings, "gtk-theme-name", "Adwaita", NULL);
     else if (override_theme)
       g_object_set (gtk_settings, "gtk-theme-name", theme_name, NULL);
+    else
+      gtk_settings_reset_property (gtk_settings, "gtk-theme-name");
   }
 
   g_signal_handlers_unblock_by_func (gtk_settings,
@@ -572,7 +574,7 @@ hdy_style_manager_class_init (HdyStyleManagerClass *klass)
    *
    * The [property@StyleManager:system-supports-color-schemes] property can be
    * used to check if the current environment provides a color scheme
-   * dddpreference.
+   * preference.
    *
    * Since: 1.6
    */
