@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2018 Purism SPC
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -9,22 +9,31 @@
 
 #include <glib/gi18n-lib.h>
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
 /**
- * SECTION:hdy-title-bar
- * @short_description: A simple title bar container.
- * @Title: HdyTitleBar
+ * HdyTitleBar:
  *
- * HdyTitleBar is meant to be used as the top-level widget of your window's
- * title bar. It will be drawn with the same style as a GtkHeaderBar but it
- * won't force a widget layout on you: you can put whatever widget you want in
- * it, including a GtkHeaderBar.
+ * A simple title bar container.
  *
- * HdyTitleBar becomes really useful when you want to animate header bars, like
- * an adaptive application using #HdyLeaflet would do.
+ * `HdyTitleBar` is meant to be used as the top-level widget of your window's
+ * title bar. It will be drawn with the same style as a [class@Gtk.HeaderBar]
+ * but it won't force a widget layout on you: you can put whatever widget you
+ * want in it, including a [class@Gtk.HeaderBar].
  *
- * # CSS nodes
+ * `HdyTitleBar` becomes really useful when you want to animate header bars,
+ * like an adaptive application using [class@Leaflet] would do.
  *
- * #HdyTitleBar has a single CSS node with name headerbar.
+ * `HdyTitleBar` has been deprecated, header bars can be animated without it
+ * when placed inside [class@Window] or [class@ApplicationWindow].
+ *
+ * ## CSS nodes
+ *
+ * `HdyTitleBar` has a single CSS node with name `headerbar`.
+ *
+ * Since: 1.0
+ *
+ * Deprecated: 1.4
  */
 
 enum {
@@ -45,11 +54,15 @@ G_DEFINE_TYPE (HdyTitleBar, hdy_title_bar, GTK_TYPE_BIN)
 static GParamSpec *props[LAST_PROP];
 
 /**
- * hdy_title_bar_set_selection_mode:
- * @self: a #HdyTitleBar
- * @selection_mode: %TRUE to enable the selection mode
+ * hdy_title_bar_set_selection_mode:  (attributes org.gtk.Method.set_property=selection-mode)
+ * @self: a title bar
+ * @selection_mode: `TRUE` to enable the selection mode
  *
  * Sets whether @self is in selection mode.
+ *
+ * Since: 1.0
+ *
+ * Deprecated: 1.4
  */
 void
 hdy_title_bar_set_selection_mode (HdyTitleBar *self,
@@ -77,12 +90,16 @@ hdy_title_bar_set_selection_mode (HdyTitleBar *self,
 }
 
 /**
- * hdy_title_bar_get_selection_mode:
- * @self: a #HdyTitleBar
+ * hdy_title_bar_get_selection_mode:  (attributes org.gtk.Method.get_property=selection-mode)
+ * @self: a title bar
  *
  * Returns whether whether @self is in selection mode.
  *
- * Returns: %TRUE if the title bar is in selection mode
+ * Returns: `TRUE` if the title bar is in selection mode
+ *
+ * Since: 1.0
+ *
+ * Deprecated: 1.4
  */
 gboolean
 hdy_title_bar_get_selection_mode (HdyTitleBar *self)
@@ -299,16 +316,20 @@ hdy_title_bar_class_init (HdyTitleBarClass *klass)
   widget_class->size_allocate = hdy_title_bar_size_allocate;
 
   /**
-   * HdyTitleBar:selection_mode:
+   * HdyTitleBar:selection-mode: (attributes org.gtk.Property.get=hdy_title_bar_set_selection_mode org.gtk.Property.set=hdy_title_bar_set_selection_mode)
    *
-   * %TRUE if the title bar is in selection mode.
+   * Whether or not the title bar is in selection mode.
+   *
+   * Since: 1.0
+   *
+   * Deprecated: 1.4
    */
   props[PROP_SELECTION_MODE] =
       g_param_spec_boolean ("selection-mode",
                             _("Selection mode"),
                             _("Whether or not the title bar is in selection mode"),
                             FALSE,
-                            G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                            G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -336,12 +357,18 @@ hdy_title_bar_init (HdyTitleBar *self)
 /**
  * hdy_title_bar_new:
  *
- * Creates a new #HdyTitleBar.
+ * Creates a new `HdyTitleBar`.
  *
- * Returns: a new #HdyTitleBar
+ * Returns: a new `HdyTitleBar`
+ *
+ * Since: 1.0
+ *
+ * Deprecated: 1.4
  */
 GtkWidget *
 hdy_title_bar_new (void)
 {
   return g_object_new (HDY_TYPE_TITLE_BAR, NULL);
 }
+
+G_GNUC_END_IGNORE_DEPRECATIONS
